@@ -22,11 +22,19 @@
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 # THE SOFTWARE.
 
+import os
+import sys
+
+basedir = os.path.dirname(os.path.dirname(os.path.abspath(__file__)))
+sys.path.append(basedir)
+
 
 class Foo(object):
     foo = 'foo'
     bar = 'bar'
 
 
+bar = None
+
 import web_pdb; web_pdb.set_trace()
 pass
