@@ -45,9 +45,11 @@ class SeleniumTestCase(TestCase):
             options.add_argument('headless')
             options.add_argument('disable-gpu')
             cls.browser = webdriver.Chrome(options=options)
+        cls.browser.implicitly_wait(10)
         cls.browser.get('http://127.0.0.1:5555')
         cls.stdin = cls.browser.find_element_by_id('stdin')
         cls.send_btn = cls.browser.find_element_by_id('send_btn')
+        cls.stdout_tag = cls.browser.find_element_by_id('stdout')
 
     @classmethod
     def tearDownClass(cls):
@@ -66,13 +68,13 @@ class WebPdbTestCase(SeleniumTestCase):
     @classmethod
     def setUpClass(cls):
         cls.db_proc = Popen(['python', db_py], shell=False)
-        time.sleep(1)
         super(WebPdbTestCase, cls).setUpClass()
 
     def test_1_set_trace(self):
         """
         Test back-end/front-end interaction during debugging
         """
+        time.sleep(1)
         filename_tag = self.browser.find_element_by_id('filename')
         self.assertEqual(filename_tag.text, 'db.py')
         curr_line_tag = self.browser.find_element_by_id('curr_line')
@@ -81,8 +83,7 @@ class WebPdbTestCase(SeleniumTestCase):
         self.assertIn('foo = \'foo\'', curr_file_tag.text)
         globals_tag = self.browser.find_element_by_id('globals')
         self.assertIn('foo = \'foo\'', globals_tag.text)
-        stdout_tag = self.browser.find_element_by_id('stdout')
-        self.assertIn('-> bar = \'bar\'', stdout_tag.text)
+        self.assertIn('-> bar = \'bar\'', self.stdout_tag.text)
         # Test if Prismjs syntax coloring actually works
         self.assertIn('foo <span class="token operator">=</span> <span class="token string">\'foo\'</span>',
                       self.browser.page_source)
@@ -99,8 +100,7 @@ class WebPdbTestCase(SeleniumTestCase):
         self.assertEqual(curr_line_tag.text, '15')
         globals_tag = self.browser.find_element_by_id('globals')
         self.assertIn('bar = \'bar\'', globals_tag.text)
-        stdout_tag = self.browser.find_element_by_id('stdout')
-        self.assertIn('-> ham = \'spam\'', stdout_tag.text)
+        self.assertIn('-> ham = \'spam\'', self.stdout_tag.text)
         self.assertEqual(self.stdin.get_attribute('value'), '')
 
     def test_3_history(self):
@@ -136,8 +136,7 @@ class WebPdbTestCase(SeleniumTestCase):
         self.stdin.send_keys('n')
         self.send_btn.click()
         time.sleep(1)
-        stdout_tag = self.browser.find_element_by_id('stdout')
-        self.assertIn('-> name = u\'Монти\'', stdout_tag.text)
+        self.assertIn('-> name = u\'Монти\'', self.stdout_tag.text)
 
     def test_6_entering_unicode_string(self):
         """
@@ -171,25 +170,24 @@ class PatchStdStreamsTestCase(SeleniumTestCase):
     @classmethod
     def setUpClass(cls):
         cls.db_proc = Popen(['python', os.path.join(cwd, 'db_ps.py')], shell=False)
-        time.sleep(1)
         super(PatchStdStreamsTestCase, cls).setUpClass()
 
     def test_patching_std_streams(self):
         """
         Test if std streams are correctly redirected to the web-console
         """
+        time.sleep(1)
         self.stdin.send_keys('n')
         self.send_btn.click()
         time.sleep(1)
-        stdout_tag = self.browser.find_element_by_id('stdout')
-        self.assertIn('Enter something:', stdout_tag.text)
+        self.assertIn('Enter something:', self.stdout_tag.text)
         self.stdin.send_keys('spam')
         self.send_btn.click()
         time.sleep(1)
         self.stdin.send_keys('n')
         self.send_btn.click()
         time.sleep(1)
-        self.assertIn('You have entered: spam', stdout_tag.text)
+        self.assertIn('You have entered: spam', self.stdout_tag.text)
 
 
 class CatchPostMortemTestCase(SeleniumTestCase):
@@ -199,13 +197,13 @@ class CatchPostMortemTestCase(SeleniumTestCase):
     @classmethod
     def setUpClass(cls):
         cls.db_proc = Popen(['python', os.path.join(cwd, 'db_pm.py')], shell=False)
-        time.sleep(1)
         super(CatchPostMortemTestCase, cls).setUpClass()
 
     def test_catch_post_mortem(self):
         """
         Test if catch_post_mortem context manager catches exceptions
         """
+        time.sleep(1)
         curr_line_tag = self.browser.find_element_by_id('curr_line')
         self.assertEqual(curr_line_tag.text, '14')
         curr_file_tag = self.browser.find_element_by_id('curr_file_code')
@@ -221,19 +219,33 @@ class InspectCommandTestCase(SeleniumTestCase):
     @classmethod
     def setUpClass(cls):
         cls.db_proc = Popen(['python', os.path.join(cwd, 'db_i.py')], shell=False)
-        time.sleep(1)
         super(InspectCommandTestCase, cls).setUpClass()
 
-    def test_inspect_command(self):
+    def test_inspect_existing_object(self):
         """
-        Test if inspect command works correctly
+        Test inspecting existing object
         """
+        time.sleep(1)
         self.stdin.send_keys('i Foo')
         self.send_btn.click()
         time.sleep(1)
-        stdout_tag = self.browser.find_element_by_id('stdout')
-        self.assertIn('foo: \'foo\'', stdout_tag.text)
-        self.assertIn('bar: \'bar\'', stdout_tag.text)
+        self.assertIn('foo: \'foo\'', self.stdout_tag.text)
+        self.assertIn('bar: \'bar\'', self.stdout_tag.text)
+        self.stdin.send_keys('i bar')
+        self.send_btn.click()
+        time.sleep(1)
+        self.assertNotIn('NameError: name "bar" is not defined',
+                         self.stdout_tag.text)
+
+    def test_inspect_non_existing_object(self):
+        """
+        Test inspecting non-existing object
+        """
+        self.stdin.send_keys('i spam')
+        self.send_btn.click()
+        time.sleep(1)
+        self.assertIn('NameError: name "spam" is not defined',
+                      self.stdout_tag.text)
 
 
 if __name__ == '__main__':
