@@ -41,7 +41,7 @@ from .web_console import WebConsole
 
 __all__ = ['WebPdb', 'set_trace', 'post_mortem', 'catch_post_mortem']
 
-__version__ = '1.5.0'
+__version__ = '1.5.6'
 
 
 class WebPdb(Pdb):
@@ -52,6 +52,7 @@ class WebPdb(Pdb):
     with extra convenience features.
     """
     active_instance = None
+    null = object()
 
     def __init__(self, host='', port=5555, patch_stdstreams=False):
         """
@@ -104,8 +105,13 @@ class WebPdb(Pdb):
         i(nspect) object
         Inspect an object
         """
-        obj = self.curframe.f_locals.get(arg) or self.curframe.f_globals.get(arg)
-        if obj is not None:
+        if arg in self.curframe_locals:
+            obj = self.curframe_locals[arg]
+        elif arg in self.curframe.f_globals:
+            obj = self.curframe.f_globals[arg]
+        else:
+            obj = WebPdb.null
+        if obj is not WebPdb.null:
             self.console.writeline(
                 '{0} = {1}:\n'.format(arg, type(obj))
             )
@@ -161,6 +167,7 @@ class WebPdb(Pdb):
             if not self.console.closed:
                 self.console.flush()
                 self.console.close()
+                WebPdb.active_instance = None
         return ret
 
     def get_current_frame_data(self):
@@ -223,7 +230,7 @@ class WebPdb(Pdb):
         :return: a listing of ``var = value`` pairs sorted alphabetically
         :rtype: unicode
         """
-        return self._format_variables(self.curframe.f_locals)
+        return self._format_variables(self.curframe_locals)
 
     def remove_trace(self, frame=None):
         """
